==> xaraya-1.1.2.tbz: www/xaraya/modules/registration/xarversion.php <==
<?php
/**
 * Registration module initialization
 *
 * @package modules
 * @copyright (C) 2002-2006 The Digital Development Foundation
 * @license GPL {@link http://www.gnu.org/licenses/gpl.html}
 * @link http://www.xaraya.com
 *
 * @subpackage Registration module
 * @link http://xaraya.com/index.php/release/30205.html
 * @author Jo Dalle Nogare <jojodee@xaraya.com>
 */

/* WARNING
 * Modification of this file is not supported.
 * Any modification is at your own risk and
 * may lead to inablity of the system to process
 * the file correctly, resulting in unexpected results.
 */
$modversion['name']           = 'registration';
$modversion['id']             = '30205';
$modversion['version']        = '1.0.0';
$modversion['displayname']    = xarML('User Registration');
$modversion['description']    = 'Standard User Registration';
$modversion['displaydescription'] = xarML('Standard User Registration');
$modversion['credits']        = 'xardocs/credits.txt';
$modversion['help']           = 'xardocs/help.txt';
$modversion['changelog']      = 'xardocs/changelog.txt';
$modversion['license']        = 'xardocs/license.txt';
$modversion['official']       = 1;
$modversion['author']         = 'Jim McDonald, Marco Canini, Jan Schrage, Camille Perinel';
$modversion['contact']        = 'http://www.mcdee.net/, marco@xaraya.com, jan@xaraya.com, kams@xaraya.com';
$modversion['admin']          = 1;
$modversion['user']           = 1;
$modversion['class']          = 'Registration';
$modversion['category']       = 'Users & Groups';
$modversion['dependency'] = array(27,42);
$modversion['dependencyinfo'] = array(27 => 'roles',42=>'authsystem');
?>

==> xaraya-1.1.4.tbz: www/xaraya/modules/registration/xarversion.php <==
<?php
/**
 * Registration module initialization
 *
 * @package modules
 * @copyright (C) 2002-2006 The Digital Development Foundation
 * @license GPL {@link http://www.gnu.org/licenses/gpl.html}
 * @link http://www.xaraya.com
 *
 * @subpackage Registration module
 * @link http://xaraya.com/index.php/release/30205.html
 * @author Jo Dalle Nogare <jojodee@xaraya.com>
 */

/* WARNING
 * Modification of this file is not supported.
 * Any modification is at your own risk and
 * may lead to inability of the system to process
 * the file correctly, resulting in unexpected results.
 */
$modversion['name']           = 'registration';
$modversion['id']             = '30205';
$modversion['version']        = '1.0.3';
$modversion['displayname']    = xarML('User Registration');
$modversion['description']    = 'Standard User Registration';
$modversion['displaydescription'] = xarML('Standard User Registration');
$modversion['credits']        = 'xardocs/credits.txt';
$modversion['help']           = 'xardocs/help.txt';
$modversion['changelog']      = 'xardocs/changelog.txt';
$modversion['license']        = 'xardocs/license.txt';
$modversion['official']       = 1;
$modversion['author']         = 'Jim McDonald, Marco Canini, Jan Schrage, Camille Perinel';
$modversion['contact']        = 'http://www.mcdee.net/, marco@xaraya.com, jan@xaraya.com, kams@xaraya.com';
$modversion['admin']          = 1;
$modversion['user']           = 1;
$modversion['class']          = 'Registration';
$modversion['category']       = 'Users & Groups';
$modversion['dependency']     = array(27,42);
$modversion['dependencyinfo'] = array(27 => 'roles',42=>'authsystem');
?>
